﻿namespace SourceGit.Models
{
    public enum ImageDecoder
    {
        None = 0,
        Builtin,
        Pfim,
        Tiff,
    }
}
